#ifndef NT2_INCLUDE_FUNCTIONS_HJMIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_HJMIN_HPP_INCLUDED

#include <nt2/optimization/include/functions/hjmin.hpp>

#endif
